@@ -1,4 +1,4 @@
-import time
+import random
 import simplejson
 import pkg_resources
 
@@ -31,7 +31,8 @@ class TurboFlot(Widget):
                   JSLink("turboflot", "jquery.flot.js")]
 
     def __init__(self, data, options={}, height="300px", width="600px"):
-        self.id = str(time.time()).split('.')[0]
+        random.seed()
+        self.id = int(random.random() * 1000)
         self.data = simplejson.dumps(data)
         self.options = simplejson.dumps(options)
         self.height = height
